@@ -1,6 +1,5 @@
 """Top-level package for glacier-flow-model."""
-
-from glacier_flow_model.model import GlacierFlowModel
 from glacier_flow_model.data import PkgDataAccess
+from glacier_flow_model.model import GlacierFlowModel
 
-__all__ = ['GlacierFlowModel', 'PkgDataAccess']
+__all__ = ["GlacierFlowModel", "PkgDataAccess"]
